Package 'OncoTree'
| Title: |
Expose the OncoTree API for R |
| Description: |
Expose the OncoTree API for R. OncoTree is a standardized
ontology of cancer terms that is used to annotate cancer data.
This package provides a set of functions to query the OncoTree
API and retrieve information about cancer types, subtypes, and
their relationships. |
| Authors: |
Marcel Ramos [aut, cre] (ORCID:
<https://orcid.org/0000-0002-3242-0582>) |
| Maintainer: |
Marcel Ramos <[email protected]> |
| License: |
Artistic-2.0 |
| Version: |
0.0.0.9000 |
| Built: |
2026-06-03 06:42:05 UTC |
| Source: |
https://github.com/LiNk-NY/OncoTree |
Help Index